@@ -1,10 +1,16 @@
 #!/bin/sh
-
+###################
+# This is property of eXtremeSHOK.com
+# You are free to use, modify and distribute, however you may not remove this notice.
+# Copyright (c) Adrian Jon Kriel :: admin@extremeshok.com
+##################
+# 
+# Originially based on: 
 # This script freely provided by Bill Landry (unofficialsigs@gmail.com).
 # Comments, suggestions, and recommendations for improving this script
 # are always welcome.
 #
-# Script updates can be found at: http://sourceforge.net/projects/unofficial-sigs
+# Script updates can be found at: https://github.com/extremeshok/clamav-unofficial-sigs
 #
 # License: BSD (Berkeley Software Distribution)
 
@@ -13,12 +19,14 @@
 #            THERE ARE NO USER CONFIGURABLE OPTIONS IN THIS SCRIPT             #
 #                                    * * *                                     #
 #   ALL CONFIGURATION OPTIONS ARE LOCATED IN THE INCLUDED CONFIGURATION FILE   #
+#                                    * * *                                     #
+#                NOT COMPATIBLE WITH VERSION 3.XX CONFIG                       #
 #                                                                              #
 ################################################################################
 
 default_config="/etc/clamav-unofficial-sigs.conf"
 
-version="v3.7.2 (updated 2013-08-25)"
+version="v4.0.0 (updated 2015-05-08)"
 output_ver="
    `basename $0` $version
 "
@@ -30,15 +38,6 @@ ClamAV Unofficial Signature Databases Update Script - $version
 
    Usage: `basename $0` [OPTION] [PATH|FILE]
 
-        -b      DEPRECATED - Consider using -w instead, it supports
-                the newer ClamAV signature whitelist funtionality.
-                ----------------------------------------------------------
-                Add a bypass signature entry to local.ign in order to
-                temporarily resolve a false-positive issue with a specific
-                third-party signature.  The script added local.ign entries
-                will automatically be removed if the original signature is
-                either modified or removed from the third-party database.
-
         -c      Direct script to use a specific configuration file
                 e.g.: '-c /path/to/`basename "$default_config"`'.
 
@@ -110,64 +109,8 @@ perms () {
 }
 
 # Take input from the commandline and process.
-while getopts 'bc:defg:himrs:tvw' option ; do
+while getopts 'c:defg:himrs:tvw' option ; do
    case $option in
-      b)  no_default_config
-          echo "Input a third-party signature name that you wish to bypass due to false-positives"
-          echo "and press enter (do not include '.UNOFFICIAL' in the signature name nor add quote"
-          echo "marks to any input string):"
-          echo ""
-          read input
-          if [ -n "$input" ]
-             then
-                cd "$clam_dbs"
-                input=`echo "$input" | tr -d "'" | tr -d '"'`
-                file_sig=`grep -n "$input:" *.ndb`
-                sig_ign=`echo "$file_sig" | cut -d ":" -f-3`
-                if [ -n "$sig_ign" ]
-                   then
-                      if ! grep "$sig_ign" local.ign > /dev/null 2>&1
-                         then
-                            cp -f local.ign "$config_dir" 2>/dev/null
-                            echo "$sig_ign" | tr -d "\r" >> "$config_dir/local.ign"
-                            echo "$file_sig" | tr -d "\r" >> "$config_dir/monitor-ign.txt"
-                            if clamscan --quiet -d "$config_dir/local.ign" "$config_dir/scan-test.txt"
-                               then
-                                  if rsync -pcqt $config_dir/local.ign $clam_dbs
-                                     then
-                                        perms chown $clam_user:$clam_group local.ign
-                                        chmod 0644 local.ign "$config_dir/monitor-ign.txt"
-                                        $reload_opt
-                                        echo ""
-                                        echo "Signature '$input' has been added to the local.ign signature bypass"
-                                        echo "file and databases have been reloaded.  The script will track any changes to the"
-                                        echo "offending third-party signature and will automatically remove the signature bypass"
-                                        echo "entry if either the signature is modified or removed from the third-party database."
-                                     else
-                                        echo ""
-                                        echo "Failed to successfully update local.ign file - SKIPPING."
-                                  fi
-                               else
-                                  echo ""
-                                  echo "Clamscan reports local.ign database integrity is bad - SKIPPING."
-                            fi
-                         else
-                            echo ""
-                            echo "Signature '$input' already exists in local.ign - no action taken."
-                      fi
-                   else
-                      echo ""
-                      echo "Signature '$input' could not be found."
-                      echo ""
-                      echo "This script will only create a bypass entry in local.ign for ClamAV"
-                      echo "'UNOFFICIAL' third-Party signatures as found in the *.ndb databases."
-                fi
-             else
-                echo "No input detected - no action taken."
-          fi
-          echo ""
-          exit
-          ;;
       c)  conf_file="$OPTARG"
           ;;
       d)  no_default_config
@@ -234,11 +177,9 @@ while getopts 'bc:defg:himrs:tvw' option ; do
              then
                 echo "GPG signature testing database file: $ss_dir/$db_file"
                 echo ""
-                if ! gpg --trust-model always -q --no-default-keyring --homedir $gpg_dir --keyring $gpg_dir/ss-keyring.gpg \
-                     --verify $ss_dir/$db_file.sig $ss_dir/$db_file
+                if ! gpg --trust-model always -q --no-default-keyring --homedir $gpg_dir --keyring $gpg_dir/ss-keyring.gpg --verify $ss_dir/$db_file.sig $ss_dir/$db_file
                    then
-                     gpg --always-trust -q --no-default-keyring --homedir $gpg_dir --keyring $gpg_dir/ss-keyring.gpg \
-                     --verify $ss_dir/$db_file.sig $ss_dir/$db_file
+                     gpg --always-trust -q --no-default-keyring --homedir $gpg_dir --keyring $gpg_dir/ss-keyring.gpg --verify $ss_dir/$db_file.sig $ss_dir/$db_file
                 fi
              else
                 echo "File '$db_file' cannot be found or is not a Sanesecurity database file."
@@ -361,11 +302,9 @@ while getopts 'bc:defg:himrs:tvw' option ; do
                          line_prefix=`echo "$line" | awk -F ':' '{print $1}'`
                          if [ "$line_prefix" = "-" ]
                             then
-                               echo "$line" | cut -d ":" -f2- | perl -pe 's/(.)/sprintf("%02lx", ord $1)/eg' | \
-                               sed "s/^/$prefix\.$line_num:4:\*:/" >> "$path_file"
+                               echo "$line" | cut -d ":" -f2- | perl -pe 's/(.)/sprintf("%02lx", ord $1)/eg' | sed "s/^/$prefix\.$line_num:4:\*:/" >> "$path_file"
                             elif [ "$line_prefix" = "=" ] ; then
-                               echo "$line" | cut -d ":" -f2- | perl -pe 's/(\{[^}]*\}|\([^)]*\)|\*)|(.)/defined \
-                               $1 ? $1 : sprintf("%02lx", ord $2)/eg' | sed "s/^/$prefix\.$line_num:4:\*:/" >> "$path_file"
+                               echo "$line" | cut -d ":" -f2- | perl -pe 's/(\{[^}]*\}|\([^)]*\)|\*)|(.)/defined $1 ? $1 : sprintf("%02lx", ord $2)/eg' | sed "s/^/$prefix\.$line_num:4:\*:/" >> "$path_file"
                             else
                                echo "$line" | perl -pe 's/(.)/sprintf("%02lx", ord $1)/eg' | sed "s/^/$prefix\.$line_num:4:\*:/" >> "$path_file"
                          fi
@@ -439,16 +378,21 @@ while getopts 'bc:defg:himrs:tvw' option ; do
                                rm -f -- "$file"
                                echo "     Removed file: $file"
                             done
-                            cron_file=`find /etc/ -name clamav-unofficial-sigs-cron`
+                            cron_file="/etc/cron.d/clamav-unofficial-sigs-cron"
                             if [ -s "$cron_file" ] ; then
                                rm -f "$cron_file"
                                echo "     Removed file: $cron_file"
                             fi
-                            log_rotate_file=`find /etc/ -name clamav-unofficial-sigs-logrotate`
+                            log_rotate_file="/etc/logrotate.d/clamav-unofficial-sigs-logrotate"
                             if [ -s "$log_rotate_file" ] ; then
                                rm -f "$log_rotate_file"
                                echo "     Removed file: $log_rotate_file"
                             fi
+                            man_file="/usr/share/man/man8/clamav-unofficial-sigs.8"
+                            if [ -s "$man_file" ] ; then
+                               rm -f "$man_file"
+                               echo "     Removed file: $man_file"
+                            fi
                             rm -f -- "$default_config" && echo "     Removed file: $default_config"
                             rm -f -- "$0" && echo "     Removed file: $0"
                             rm -rf -- "$work_dir" && echo "     Removed script working directories: $work_dir"
@@ -481,7 +425,7 @@ while getopts 'bc:defg:himrs:tvw' option ; do
                 echo "File '$input' cannot be found."
                 echo "Here is a list of third-party databases that can be clamscan integrity tested:"
                 echo ""
-                echo "Sanesecurity $ss_dbs""SecuriteInfo $si_dbs""MalwarePatrol $mbl_dbs"
+                echo "Sanesecurity $ss_dbs"
                 echo "Check the file name and try again..."
           fi
           echo ""
@@ -603,7 +547,8 @@ if [ "$1" = -c ] ;
       config_source="$default_config"
 fi
 
-. "$config_source"
+clean_config=`sed -e 's/#.*$//' -e '/^\s*$/d' "$config_source"`
+eval "$clean_config"
 
 ################################################################################
 
@@ -669,15 +614,14 @@ fi
 
 # Check to see if the working directories have been created.
 # If not, create them.  Otherwise, ignore and proceed with script.
-mkdir -p "$work_dir" "$ss_dir" "$si_dir" "$mbl_dir" "$config_dir" "$gpg_dir" "$add_dir"
+mkdir -p "$work_dir" "$ss_dir" "$config_dir" "$gpg_dir" "$add_dir"
 
 # Set secured access permissions to the GPG directory
 chmod 0700 "$gpg_dir"
 
 # If we haven't done so yet, download Sanesecurity public GPG key and import to custom keyring.
 if [ ! -s "$gpg_dir/publickey.gpg" ] ; then
-   if ! curl -s -S $curl_proxy --connect-timeout "$curl_connect_timeout" --max-time "$curl_max_time" \
-        -L -R http://www.sanesecurity.net/publickey.gpg -o $gpg_dir/publickey.gpg
+   if ! curl -s -S $curl_proxy --connect-timeout "$curl_connect_timeout" --max-time "$curl_max_time" -L -R "$ss_gpg_url" -o $gpg_dir/publickey.gpg
       then
          echo ""
          echo "Could not download Sanesecurity public GPG key"
@@ -689,8 +633,7 @@ if [ ! -s "$gpg_dir/publickey.gpg" ] ; then
          comment ""
          log "INFO - Sanesecurity public GPG key successfully downloaded"
          rm -f -- "$gpg_dir/ss-keyring.gp*"
-         if ! gpg -q --no-options --no-default-keyring --homedir $gpg_dir --keyring $gpg_dir/ss-keyring.gpg \
-              --import $gpg_dir/publickey.gpg 2>/dev/null
+         if ! gpg -q --no-options --no-default-keyring --homedir $gpg_dir --keyring $gpg_dir/ss-keyring.gpg --import $gpg_dir/publickey.gpg 2>/dev/null
             then
                echo "Could not import Sanesecurity public GPG key to custom keyring"
                log "ALERT - Could not import Sanesecurity public GPG key to custom keyring"
@@ -752,11 +695,6 @@ if [ ! -s "$config_dir/scan-test.txt" ] ; then
    echo "This is the clamscan test file..." > "$config_dir/scan-test.txt"
 fi
 
-# Unofficial ClamAV database provider URLs
-ss_url="rsync.sanesecurity.net"
-si_url="clamav.securiteinfo.com"
-mbl_url="www.malwarepatrol.net"
-
 # Create the Sanesecurity rsync "include" file (defines which files to download).
 ss_include_dbs="$config_dir/ss-include-dbs.txt"
 if [ -n "$ss_dbs" ] ; then
@@ -793,18 +731,6 @@ if [ -n "$ss_dbs" ] ; then
       clamav_files
    done
 fi
-if [ -n "$si_dbs" ] ; then
-   for db in $si_dbs ; do
-      echo "$si_dir/$db" >> "$current_tmp"
-      clamav_files
-   done
-fi
-if [ -n "$mbl_dbs" ] ; then
-   for db in $mbl_dbs ; do
-      echo "$mbl_dir/$db" >> "$current_tmp"
-      clamav_files
-   done
-fi
 if [ -n "$add_dbs" ] ; then
    for db in $add_dbs ; do
       echo "$add_dir/$db" >> "$current_tmp"
@@ -837,7 +763,6 @@ purge="$config_dir/purge.txt"
 cp -f "$current_dbs" "$purge"
 echo "$config_dir/current-dbs.txt" >> "$purge"
 echo "$config_dir/db-changes.txt" >> "$purge"
-echo "$config_dir/last-mbl-update.txt" >> "$purge"
 echo "$config_dir/last-si-update.txt" >> "$purge"
 echo "$config_dir/local.ign" >> "$purge"
 echo "$config_dir/monitor-ign.txt" >> "$purge"
@@ -881,8 +806,7 @@ if [ -n "$clamd_socket" ] ; then
    if [ "`perl -e 'use IO::Socket::UNIX; print $IO::Socket::UNIX::VERSION,"\n"' 2>/dev/null`" ]
       then
          io_socket1=1
-         if [ "`perl -MIO::Socket::UNIX -we '$s = IO::Socket::UNIX->new(shift); $s->print("PING"); \
-            print $s->getline; $s->close' "$clamd_socket" 2>/dev/null`" = "PONG" ] ; then
+         if [ "`perl -MIO::Socket::UNIX -we '$s = IO::Socket::UNIX->new(shift); $s->print("PING"); print $s->getline; $s->close' "$clamd_socket" 2>/dev/null`" = "PONG" ] ; then
             io_socket2=1
             comment "===================="
             comment "= ClamD is running ="
@@ -931,8 +855,7 @@ if [ -n "$clamd_socket" ] ; then
                   then
                      rm -f -- "$clamd_pid" "$clamd_lock" "$clamd_socket" 2>/dev/null
                      $start_clamd > /dev/null && sleep 5
-                     if [ "`perl -MIO::Socket::UNIX -we '$s = IO::Socket::UNIX->new(shift); $s->print("PING"); \
-                        print $s->getline; $s->close' "$clamd_socket" 2>/dev/null`" = "PONG" ]
+                     if [ "`perl -MIO::Socket::UNIX -we '$s = IO::Socket::UNIX->new(shift); $s->print("PING"); print $s->getline; $s->close' "$clamd_socket" 2>/dev/null`" = "PONG" ]
                         then
                            echo "=================================="
                            echo "= ClamD was successfully started ="
@@ -983,32 +906,6 @@ if [ -n "$clamd_socket" ] ; then
    fi
 fi
 
-# Check and save current system time since epoch for time related database downloads.
-# However, if unsuccessful, issue a warning that we cannot calculate times since epoch.
-if [ -n "$si_dbs" -o -n "mbl_dbs" ]
-   then
-      if [ `date +%s` -gt 0 2>/dev/null ]
-         then
-            current_time=`date +%s`
-         else
-            if [ `perl -le print+time 2>/dev/null` ] ; then
-               current_time=`perl -le print+time`
-            fi
-      fi
-   else
-      echo ""
-      echo "                           --- WARNING ---"
-      echo "The system's date function does not appear to support 'date +%s', nor was 'perl' found"
-      echo "on the system.  The SecuriteInfo and MalwarePatrol updates were bypassed at this time."
-      echo ""
-      echo "You can silence this warning by either commenting out the 'si_dbs' and 'mbl_dbs'"
-      echo "variables in the 'USER CONFIGURATION' section of the script, or by installing perl or"
-      echo "the GNU date utility, either of which can calculate the needed seconds since epoch."
-      log "WARNING - Systems does not support calculating time since epoch, SecuriteInfo and MalwarePatrol updates bypassed"
-      si_dbs=""
-      mbl_dbs=""
-fi
-
 ################################################################
 # Check for Sanesecurity database & GPG signature file updates #
 ################################################################
@@ -1025,8 +922,8 @@ if [ -n "$ss_dbs" ] ; then
       comment ""
       comment "Sanesecurity mirror site used: $ss_mirror_site_info"
       log "INFO - Sanesecurity mirror site used: $ss_mirror_site_info"
-      if rsync $rsync_output_level $no_motd --files-from=$ss_include_dbs -ctuz $connect_timeout \
-         --timeout="$rsync_max_time" --stats rsync://$ss_mirror_ip/sanesecurity $ss_dir 2>/dev/null
+      rsync $rsync_output_level $no_motd --files-from=$ss_include_dbs -ctuz $connect_timeout --timeout="$rsync_max_time" --stats rsync://$ss_mirror_ip/sanesecurity $ss_dir
+      if [ "$?" -eq "0" ] #the correct way
          then
             ss_rsync_success="1"
             for db_file in $ss_dbs ; do
@@ -1127,259 +1024,6 @@ if [ -n "$ss_dbs" ] ; then
    fi
 fi
 
-#######################################################################
-# Check for updated SecuriteInfo database files every set number of   #
-# hours as defined in the "USER CONFIGURATION" section of this script #
-#######################################################################
-if [ -n "$si_dbs" ] ; then
-   rm -f "$si_dir/*.gz"
-   if [ -s "$config_dir/last-si-update.txt" ]
-      then
-         last_si_update=`cat $config_dir/last-si-update.txt`
-      else
-         last_si_update="0"
-   fi
-   db_file=""
-   loop=""
-   update_interval=$(($si_update_hours * 3600))
-   time_interval=$(($current_time - $last_si_update))
-   if [ "$time_interval" -ge $(($update_interval - 600)) ]
-      then
-         echo "$current_time" > "$config_dir"/last-si-update.txt
-         comment ""
-         comment "======================================================================"
-         comment "SecuriteInfo Database File Updates"
-         comment "======================================================================"
-         log "INFO - Checking for SecuriteInfo updates..."
-         si_updates="0"
-         for db_file in $si_dbs ; do
-            if [ "$loop" = "1" ]
-               then
-                  comment "---"
-               else
-                  comment ""
-            fi
-            comment "Checking for updated SecuriteInfo database file: $db_file"
-            comment ""
-            si_db_update="0"
-            if [ -s "$si_dir/$db_file" ]
-               then
-                  z_opt="-z $si_dir/$db_file"
-               else
-                  z_opt=""
-            fi
-            if curl $curl_proxy $curl_output_level --connect-timeout "$curl_connect_timeout" \
-               --max-time "$curl_max_time" -L -R $z_opt -o $si_dir/$db_file http://$si_url/$db_file
-               then
-                  loop="1"
-                  if ! cmp -s $si_dir/$db_file $clam_dbs/$db_file ; then
-                     if [ "$?" = "0" ] ; then
-                        db_ext=`echo $db_file | cut -d "." -f2`
-			comment ""
-                        comment "Testing updated SecuriteInfo database file: $db_file"
-                        log "INFO - Testing updated SecuriteInfo database file: $db_file"
-                        if [ -z "$ham_dir" -o "$db_ext" != "ndb" ]
-                           then
-                              if clamscan --quiet -d "$si_dir/$db_file" "$config_dir/scan-test.txt" 2>/dev/null
-                                 then
-                                    comment "Clamscan reports SecuriteInfo $db_file database integrity tested good"
-                                    log "INFO - Clamscan reports SecuriteInfo $db_file database integrity tested good" ; true
-                                 else
-                                    echo "Clamscan reports SecuriteInfo $db_file database integrity tested BAD - SKIPPING"
-                                    log "WARNING - Clamscan reports SecuriteInfo $db_file database integrity tested BAD - SKIPPING" ; false
-                                    rm -f "$si_dir/$db_file"
-                              fi && \
-                              (test "$keep_db_backup" = "yes" && cp -f $clam_dbs/$db_file $clam_dbs/$db_file-bak 2>/dev/null ; true) && \
-                              if rsync -pcqt $si_dir/$db_file $clam_dbs
-                                 then
-                                    perms chown $clam_user:$clam_group $clam_dbs/$db_file
-                                    comment "Successfully updated SecuriteInfo production database file: $db_file"
-                                    log "INFO - Successfully updated SecuriteInfo production database file: $db_file"
-                                    si_updates=1
-                                    si_db_update=1
-                                    do_clamd_reload=1
-                                 else
-                                    echo "Failed to successfully update SecuriteInfo production database file: $db_file - SKIPPING"
-                                    log "WARNING - Failed to successfully update SecuriteInfo production database file: $db_file - SKIPPING"
-                              fi
-                           else
-                              grep -h -v -f "$config_dir/whitelist.hex" "$si_dir/$db_file" > "$test_dir/$db_file"
-                              clamscan --infected --no-summary -d "$test_dir/$db_file" "$ham_dir"/* | \
-                              sed 's/\.UNOFFICIAL FOUND//' | awk '{print $NF}' > "$config_dir/whitelist.txt"
-                              grep -h -f "$config_dir/whitelist.txt" "$test_dir/$db_file" | \
-                              cut -d "*" -f2 | sort | uniq >> "$config_dir/whitelist.hex"
-                              grep -h -v -f "$config_dir/whitelist.hex" "$test_dir/$db_file" > "$test_dir/$db_file-tmp"
-                              mv -f "$test_dir/$db_file-tmp" "$test_dir/$db_file"
-                              if clamscan --quiet -d "$test_dir/$db_file" "$config_dir/scan-test.txt" 2>/dev/null
-                                 then
-                                    comment "Clamscan reports SecuriteInfo $db_file database integrity tested good"
-                                    log "INFO - Clamscan reports SecuriteInfo $db_file database integrity tested good" ; true
-                                 else
-                                    echo "Clamscan reports SecuriteInfo $db_file database integrity tested BAD - SKIPPING"
-                                    log "WARNING - Clamscan reports SecuriteInfo $db_file database integrity tested BAD - SKIPPING" ; false
-                                    rm -f "$si_dir/$db_file"
-                              fi && \
-                              (test "$keep_db_backup" = "yes" && cp -f $clam_dbs/$db_file $clam_dbs/$db_file-bak 2>/dev/null ; true) && \
-                              if rsync -pcqt $test_dir/$db_file $clam_dbs
-                                 then
-                                    perms chown $clam_user:$clam_group $clam_dbs/$db_file
-                                    comment "Successfully updated SecuriteInfo production database file: $db_file"
-                                    log "INFO - Successfully updated SecuriteInfo production database file: $db_file"
-                                    si_updates=1
-                                    si_db_update=1
-                                    do_clamd_reload=1
-                                 else
-                                    echo "Failed to successfully update SecuriteInfo production database file: $db_file - SKIPPING"
-                                    log "WARNING - Failed to successfully update SecuriteInfo production database file: $db_file - SKIPPING"
-                              fi
-                        fi
-                     fi
-                  fi
-               else
-                  log "WARNING - Failed curl connection to $si_url - SKIPPED SecuriteInfo $db_file update"
-            fi
-            if [ "$si_db_update" != "1" ] ; then
-               comment ""
-               comment "No updated SecuriteInfo $db_file database file found"
-            fi
-         done
-         if [ "$si_updates" != "1" ] ; then
-            log "INFO - No SecuriteInfo database file updates found"
-         fi
-      else
-         comment ""
-         comment "======================================================================"
-         comment "SecuriteInfo Database File Updates"
-         comment "======================================================================"
-         comment ""
-         time_remaining=$(($update_interval - $time_interval))
-         hours_left=$(($time_remaining / 3600))
-         minutes_left=$(($time_remaining % 3600 / 60))
-         comment "$si_update_hours hours have not yet elapsed since the last SecuriteInfo update check"
-         comment ""
-         comment "     --- No update check was performed at this time ---"
-         comment ""
-         comment "Next check will be performed in approximately $hours_left hour(s), $minutes_left minute(s)"
-         log "INFO - Next SecuriteInfo check will be performed in approximately $hours_left hour(s), $minutes_left minute(s)"
-   fi
-fi
-
-#####################################################################
-# Download MalwarePatrol database file(s) every set number of hours #
-# as defined in the "USER CONFIGURATION" section of this script.    #
-#####################################################################
-if [ -n "$mbl_dbs" ] ; then
-   if [ -s "$config_dir/last-mbl-update.txt" ]
-      then
-         last_mbl_update=`cat $config_dir/last-mbl-update.txt`
-      else
-         last_mbl_update="0"
-   fi
-   db_file=""
-   update_interval=$(($mbl_update_hours * 3600))
-   time_interval=$(($current_time - $last_mbl_update))
-   if [ "$time_interval" -ge $(($update_interval - 600)) ]
-      then
-         echo "$current_time" > "$config_dir"/last-mbl-update.txt
-         log "INFO - Checking for MalwarePatrol updates..."
-         for db_file in $mbl_dbs ; do
-            # Delete the old MBL (mbl.db) database file if it exists and start using the newer
-            # format (mbl.ndb) database file instead.
-            test -e $clam_dbs/$db_file -o -e $clam_dbs/$db_file-bak && rm -f -- "$clam_dbs/mbl.d*"
-            comment ""
-            comment "======================================================================"
-            comment "MalwarePatrol $db_file Database File Update"
-            comment "======================================================================"
-            comment ""
-            if curl $curl_proxy $curl_output_level -R --connect-timeout "$curl_connect_timeout" \
-               --max-time "$curl_max_time" -o $mbl_dir/$db_file http://$mbl_url/cgi/submit?action=list_clamav_ext
-               then
-                  if ! cmp -s $mbl_dir/$db_file $clam_dbs/$db_file 
-                     then
-                        if [ "$?" = "0" ] ; then
-                           db_ext=`echo $db_file | cut -d "." -f2`
-                           comment ""
-                           comment "Testing updated MalwarePatrol database file: $db_file"
-                           log "INFO - Testing updated database file: $db_file"
-                           if [ -z "$ham_dir" -o "$db_ext" != "ndb" ]
-                              then
-                                 if clamscan --quiet -d "$mbl_dir/$db_file" "$config_dir/scan-test.txt" 2>/dev/null
-                                    then
-                                       comment "Clamscan reports MalwarePatrol $db_file database integrity tested good"
-                                       log "INFO - Clamscan reports MalwarePatrol $db_file database integrity tested good" ; true
-                                    else
-                                       echo "Clamscan reports MalwarePatrol $db_file database integrity tested BAD - SKIPPING"
-                                       log "WARNING - Clamscan reports MalwarePatrol $db_file database integrity tested BAD - SKIPPING" ; false
-                                 fi && \
-                                 (test "$keep_db_backup" = "yes" && cp -f $clam_dbs/$db_file $clam_dbs/$db_file-bak 2>/dev/null ; true) && \
-                                 if rsync -pcqt $mbl_dir/$db_file $clam_dbs
-                                    then
-                                       perms chown $clam_user:$clam_group $clam_dbs/$db_file
-                                       comment "Successfully updated MalwarePatrol production database file: $db_file"
-                                       log "INFO - Successfully updated MalwarePatrol production database file: $db_file"
-                                       mbl_update=1
-                                       do_clamd_reload=1
-                                    else
-                                       echo "Failed to successfully update MalwarePatrol production database file: $db_file - SKIPPING"
-                                       log "WARNING - Failed to successfully update MalwarePatrol production database file: $db_file - SKIPPING"
-                                 fi
-                              else
-                                 grep -h -v -f "$config_dir/whitelist.hex" "$mbl_dir/$db_file" > "$test_dir/$db_file"
-                                 clamscan --infected --no-summary -d "$test_dir/$db_file" "$ham_dir"/* | \
-                                 sed 's/\.UNOFFICIAL FOUND//' | awk '{print $NF}' > "$config_dir/whitelist.txt"
-                                 grep -h -f "$config_dir/whitelist.txt" "$test_dir/$db_file" | \
-                                 cut -d "*" -f2 | sort | uniq >> "$config_dir/whitelist.hex"
-                                 grep -h -v -f "$config_dir/whitelist.hex" "$test_dir/$db_file" > "$test_dir/$db_file-tmp"
-                                 mv -f "$test_dir/$db_file-tmp" "$test_dir/$db_file"
-                                 if clamscan --quiet -d "$test_dir/$db_file" "$config_dir/scan-test.txt" 2>/dev/null
-                                    then
-                                       comment "Clamscan reports MalwarePatrol $db_file database integrity tested good"
-                                       log "INFO - Clamscan reports MalwarePatrol $db_file database integrity tested good" ; true
-                                    else
-                                       echo "Clamscan reports MalwarePatrol $db_file database integrity tested BAD - SKIPPING"
-                                       log "WARNING - Clamscan reports MalwarePatrol $db_file database integrity tested BAD - SKIPPING" ; false
-                                 fi && \
-                                 (test "$keep_db_backup" = "yes" && cp -f $clam_dbs/$db_file $clam_dbs/$db_file-bak 2>/dev/null ; true) && \
-                                 if rsync -pcqt $test_dir/$db_file $clam_dbs
-                                    then
-                                       perms chown $clam_user:$clam_group $clam_dbs/$db_file
-                                       comment "Successfully updated MalwarePatrol production database file: $db_file"
-                                       log "INFO - Successfully updated MalwarePatrol production database file: $db_file"
-                                       mbl_update=1
-                                       do_clamd_reload=1
-                                    else
-                                       echo "Failed to successfully update MalwarePatrol production database file: $db_file - SKIPPING"
-                                       log "WARNING - Failed to successfully update MalwarePatrol production database file: $db_file - SKIPPING"
-                                 fi
-                           fi
-                        fi
-                     else
-                        comment ""
-                        comment "MalwarePatrol signature database ($db_file) did not change - skipping"
-                        log "INFO - MalwarePatrol signature database ($db_file) did not change - skipping"
-                  fi
-               else
-                  log "WARNING - Failed curl connection to $mbl_url - SKIPPED MalwarePatrol $db_file update"
-            fi
-         done
-      else
-         comment ""
-         comment "======================================================================"
-         comment "MalwarePatrol Database File Update"
-         comment "======================================================================"
-         comment ""
-         time_remaining=$(($update_interval - $time_interval))
-         hours_left=$(($time_remaining / 3600))
-         minutes_left=$(($time_remaining % 3600 / 60))
-         comment "$mbl_update_hours hours have not yet elapsed since the last MalwarePatrol download"
-         comment ""
-         comment "     --- No database download was performed at this time ---"
-         comment ""
-         comment "Next download will be performed in approximately $hours_left hour(s), $minutes_left minute(s)"
-         log "INFO - Next MalwarePatrol download will be performed in approximately $hours_left hour(s), $minutes_left minute(s)"
-   fi
-fi
-
 ###################################################
 # Check for user added signature database updates #
 ###################################################
@@ -1454,16 +1098,17 @@ if [ -s "$clam_dbs/local.ign" -a -s "$config_dir/monitor-ign.txt" ] ; then
    ign_updated=0
    cd "$clam_dbs"
    cp -f local.ign "$config_dir/local.ign"
+   cp -f "$config_dir/monitor-ign.txt" "$config_dir/monitor-ign-old.txt"
    comment ""
    comment "======================================================================"
-   for entry in `cat "$config_dir/monitor-ign.txt" 2>/dev/null` ; do
+   for entry in `cat "$config_dir/monitor-ign-old.txt" 2>/dev/null` ; do
       sig_file=`echo "$entry" | tr -d "\r" | awk -F ":" '{print $1}'`
       sig_hex=`echo "$entry" | tr -d "\r" | awk -F ":" '{print $NF}'`
       sig_name_old=`echo "$entry" | tr -d "\r" | awk -F ":" '{print $3}'`
-      sig_ign_old=`grep "$sig_name_old" "$config_dir/local.ign"`
+      sig_ign_old=`grep ":$sig_name_old" "$config_dir/local.ign"`
       sig_old=`echo "$entry" | tr -d "\r" | cut -d ":" -f3-`
-      sig_new=`grep -hwF "$sig_hex" "$sig_file" | tr -d "\r" 2>/dev/null`
-      sig_mon_new=`grep -HwF -n "$sig_hex" "$sig_file" | tr -d "\r"`
+      sig_new=`grep -hwF ":$sig_hex" "$sig_file" | tr -d "\r" 2>/dev/null`
+      sig_mon_new=`grep -HwF -n ":$sig_hex" "$sig_file" | tr -d "\r"`
       if [ -n "$sig_new" ]
          then
             if [ "$sig_old" != "$sig_new" -o "$entry" != "$sig_mon_new" ] ; then
@@ -1473,10 +1118,10 @@ if [ -s "$clam_dbs/local.ign" -a -s "$config_dir/monitor-ign.txt" ] ; then
                echo "$sig_mon_new" >> "$config_dir/monitor-ign.txt"
                perl -p -i -e "s/$sig_ign_old/$sig_ign_new/" "$config_dir/local.ign"
                comment ""
-               comment "$sig_name_old hexadecimal signature unchanged, however signature name and/or line placement"
-               comment "in $sig_file has change to $sig_name_new - updated local.ign to reflect this change."
-               log "INFO - $sig_name_old hexadecimal signature unchanged, however signature name and/or line placement"
-               log "INFO - in $sig_file has change to $sig_name_new - updated local.ign to reflect this change."
+               comment "$sig_name_old hexadecimal signature is unchanged, however signature name and/or line placement"
+               comment "in $sig_file has changed to $sig_name_new - updated local.ign to reflect this change."
+               log "INFO - $sig_name_old hexadecimal signature is unchanged, however signature name and/or line placement"
+               log "INFO - in $sig_file has changed to $sig_name_new - updated local.ign to reflect this change."
                ign_updated=1
             fi
          else
